@@ -257,11 +257,17 @@ class Movie(ReloadObj):
         else:
             raise Invalid("Load Failed: No Load Input")
 
-    def _get_add_data(self, options):
+    def _get_add_data(self, options, path=None):
         if self.id:
             raise Exists(f"{self.title} is already in Radarr")
         self._data.pop("Id", None)
         self._data["monitored"] = options["monitor"]
+        if path:
+            if not path.startswith(options["root_folder"]):
+                raise Invalid(f"Individual Path: {path} must start with the Root Folder: {options['root_folder']} ")
+            self._data["path"] = path
+        else:
+            self._data["rootFolderPath"] = options["root_folder"]
         self._data["rootFolderPath"] = options["root_folder"]
         self._data["qualityProfileId" if self._raw.v3 else "profileId"] = options["quality_profile"]
         self._data["minimumAvailability"] = options["minimum_availability"]
@@ -326,7 +332,7 @@ class Movie(ReloadObj):
             Raises:
                 :class:`ValueError`: When theres no options given.
                 :class:`~arrapi.exceptions.Invalid`: When one of the options given is invalid.
-                :class:`~arrapi.exceptions.NotFound`: When the Movie isn't found in Radarr and must be added to Radarr before editing.
+                :class:`~arrapi.exceptions.NotFound`: When the Movie hasn't been added to Radarr.
         """
         if not self.id:
             raise NotFound(f"{self.title} not found Radarr, it must be added before editing")
@@ -357,7 +363,7 @@ class Movie(ReloadObj):
                 deleteFiles (bool): Delete Files for this Movie.
 
             Raises:
-                :class:`~arrapi.exceptions.NotFound`: When the Movie isn't found in Radarr.
+                :class:`~arrapi.exceptions.NotFound`: When the Movie hasn't been added to Radarr.
         """
         if not self.id:
             raise NotFound(f"{self.title} not found Radarr, it must be added before deleting")
@@ -493,11 +499,17 @@ class Series(ReloadObj):
         else:
             raise Invalid("Load Failed: No Load Input")
 
-    def _get_add_data(self, options):
+    def _get_add_data(self, options, path=None):
         if self.id:
             raise Exists(f"{self.title} is already in Sonarr")
         self._data.pop("Id", None)
         self._data["rootFolderPath"] = options["root_folder"]
+        if path:
+            if not path.startswith(options["root_folder"]):
+                raise Invalid(f"Individual Path: {path} must start with the Root Folder: {options['root_folder']} ")
+            self._data["path"] = path
+        else:
+            self._data["rootFolderPath"] = options["root_folder"]
         self._data["monitored"] = options["monitored"]
         self._data["qualityProfileId" if self._raw.v3 else "profileId"] = options["quality_profile"]
         self._data["languageProfileId"] = options["language_profile"]
@@ -582,7 +594,7 @@ class Series(ReloadObj):
             Raises:
                 :class:`ValueError`: When theres no options given.
                 :class:`~arrapi.exceptions.Invalid`: When one of the options given is invalid.
-                :class:`~arrapi.exceptions.NotFound`: When the Series isn't found in Sonarr and must be added to Sonarr before editing.
+                :class:`~arrapi.exceptions.NotFound`: When the Series hasn't been added to Sonarr.
         """
         if not self.id:
             raise NotFound(f"{self.title} not found in Sonarr, it must be added before editing")
@@ -616,7 +628,7 @@ class Series(ReloadObj):
                 deleteFiles (bool): Delete Files for this Series.
 
             Raises:
-                :class:`~arrapi.exceptions.NotFound`: When the Series isn't found in Sonarr.
+                :class:`~arrapi.exceptions.NotFound`: When the Series hasn't been added to Sonarr.
         """
         if not self.id:
             raise NotFound(f"{self.title} not found in Sonarr, it must be added before deleting")
